==> attal_0.8.orig.tar.gz: attal-0.8/i18n/ru/scenario_editor_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Раса:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Количество:</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Выберете покрытие</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Основные свойства</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Строения</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Количество созданий:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Поведение созданий:</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Никогда не отступать:</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Свойства лорда</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Юниты</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Артефакты</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Боевые машины</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Техники</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Ошибка в свойсвах лорда</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Лорд должен иметь хотя бы 1 юнит</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Общий список артефактов</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Список артефактов лорда</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Выберете игрока:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Общий список техник</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Список техник лорда</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Общий список боевых машин</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Список боевых машин лорда</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Покрытие</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Переходное покрытие</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Декорация</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Здание</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>База</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Лорд</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Артефакт</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Создание</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Инструмент</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Отмена</translation>
    </message>
    <message>
        <source>Map </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Сохранить как</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Информация о сценарии</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Информация о сценарии</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Свойства игрока</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Свойства игрока</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Очистить экран</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Очистить экран</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Заполнить экран</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Запонить экран</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Сценарий</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/ru/scenario_editor_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AskLordCharac</name>
    <message>
        <source>Charac</source>
        <translation>Персонаж</translation>
    </message>
</context>
<context>
    <name>DisplayQuests</name>
    <message>
        <source>Main quest: </source>
        <translation>Главная задача:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Other quests:</source>
        <translation>Другие задачи:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Раса:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Количество:</translation>
    </message>
</context>
<context>
    <name>FillDialog</name>
    <message>
        <source>Choose tile</source>
        <translation>Выберете покрытие</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (ширина=%d)</translation>
    </message>
</context>
<context>
    <name>NewQuestConditionDialog</name>
    <message>
        <source>AND</source>
        <translation>И</translation>
    </message>
    <message>
        <source>OR</source>
        <translation>ИЛИ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Лорд</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Игрок</translation>
    </message>
</context>
<context>
    <name>PropertiesBase</name>
    <message>
        <source>Base properties</source>
        <translation>Основные свойства</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Строения</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
<context>
    <name>PropertiesBonus</name>
    <message>
        <source>Resource: </source>
        <translation>Ресурс:</translation>
    </message>
    <message>
        <source>Fixed value: </source>
        <translation>Фиксированное значение:</translation>
    </message>
    <message>
        <source>Primary skill: </source>
        <translation>Основной навык:</translation>
    </message>
    <message>
        <source>Attack</source>
        <translation>Атака</translation>
    </message>
    <message>
        <source>Defense</source>
        <translation>Защита</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Сила</translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation>Знание</translation>
    </message>
    <message>
        <source>Morale</source>
        <translation>Мораль</translation>
    </message>
    <message>
        <source>Luck</source>
        <translation>Удача</translation>
    </message>
    <message>
        <source>Add value: </source>
        <translation>Добавить значение:</translation>
    </message>
    <message>
        <source>Bonus for secondary skills are not yet implemented</source>
        <translation>Бонус за добавочные навыки еще не реализованы</translation>
    </message>
    <message>
        <source>Bonus for spells are not yet implemented</source>
        <translation>Бонусы за заклинания еще не реализованы</translation>
    </message>
</context>
<context>
    <name>PropertiesBuilding</name>
    <message>
        <source>building properties</source>
        <translation>свойства здания</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
<context>
    <name>PropertiesCreature</name>
    <message>
        <source>Number of Creatures: </source>
        <translation type="obsolete">Количество созданий:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Behaviour of Creatures: </source>
        <translation>Поведение созданий:</translation>
    </message>
    <message>
        <source>Never flee: </source>
        <translation>Никогда не отступать:</translation>
    </message>
    <message>
        <source>Looking at right side: </source>
        <translation>Смотрит направо:</translation>
    </message>
    <message>
        <source>Number of creatures in stack %d: </source>
        <translation>Количество созданий в стеке %d:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>PropertiesEvent</name>
    <message>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>PropertiesLord</name>
    <message>
        <source>Lord properties</source>
        <translation>Свойства лорда</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Units</source>
        <translation>Юниты</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Артефакты</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Боевые машины</translation>
    </message>
    <message>
        <source>Technics</source>
        <translation>Техники</translation>
    </message>
    <message>
        <source>Lord&apos;s properties error</source>
        <translation>Ошибка в свойсвах лорда</translation>
    </message>
    <message>
        <source>The lord must have at least 1 unit</source>
        <translation>Лорд должен иметь хотя бы 1 юнит</translation>
    </message>
</context>
<context>
    <name>PropertiesLordArtefacts</name>
    <message>
        <source>Common artefacts list</source>
        <translation>Общий список артефактов</translation>
    </message>
    <message>
        <source>Lord&apos;s artefacts list</source>
        <translation>Список артефактов лорда</translation>
    </message>
</context>
<context>
    <name>PropertiesLordGeneral</name>
    <message>
        <source>Select player:</source>
        <translation>Выберете игрока:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>PropertiesLordTechnics</name>
    <message>
        <source>Common technics list</source>
        <translation>Общий список техник</translation>
    </message>
    <message>
        <source>Lord&apos;s technics list</source>
        <translation>Список техник лорда</translation>
    </message>
</context>
<context>
    <name>PropertiesLordWarMachines</name>
    <message>
        <source>Common war machines list</source>
        <translation>Общий список боевых машин</translation>
    </message>
    <message>
        <source>Lord&apos;s war machines list</source>
        <translation>Список боевых машин лорда</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tile</source>
        <translation>Покрытие</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Переходное покрытие</translation>
    </message>
    <message>
        <source>Decoration</source>
        <translation>Декорация</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Здание</translation>
    </message>
    <message>
        <source>Base</source>
        <translation>База</translation>
    </message>
    <message>
        <source>Lord</source>
        <translation>Лорд</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Артефакт</translation>
    </message>
    <message>
        <source>Creature</source>
        <translation>Создание</translation>
    </message>
    <message>
        <source>Tool</source>
        <translation>Инструмент</translation>
    </message>
    <message>
        <source>Bonus</source>
        <translation>Бонус</translation>
    </message>
</context>
<context>
    <name>QuestConditionDateProperties</name>
    <message>
        <source>Before date: </source>
        <translation>Предыдущая дата:</translation>
    </message>
    <message>
        <source>Day</source>
        <translation>День</translation>
    </message>
    <message>
        <source>Week</source>
        <translation>Неделя</translation>
    </message>
    <message>
        <source>Month</source>
        <translation>Месяц</translation>
    </message>
    <message>
        <source>Before </source>
        <translation>Перед</translation>
    </message>
    <message>
        <source>day(s)</source>
        <translation>День(дни)</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QuestConditionDialog</name>
    <message>
        <source>Condition</source>
        <translation>Условие</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation>&amp;Свойства</translation>
    </message>
    <message>
        <source>&amp;Add condition</source>
        <translation>&amp;Добавить условие</translation>
    </message>
    <message>
        <source>&amp;Delete condition</source>
        <translation>&amp;Удалить условие</translation>
    </message>
</context>
<context>
    <name>QuestConditionEditor</name>
    <message>
        <source>Condition: </source>
        <translation>Условие:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
</context>
<context>
    <name>QuestConditionLordProperties</name>
    <message>
        <source>Primary skill</source>
        <translation>Основной навык</translation>
    </message>
    <message>
        <source>value: </source>
        <translation>значение:</translation>
    </message>
    <message>
        <source>Secondary skill</source>
        <translation>Вторичный навык</translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation>Артефакт</translation>
    </message>
    <message>
        <source>Spell</source>
        <translation>Заклинание</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QuestEditor</name>
    <message>
        <source>Name: </source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Ask player confirmation of quest</source>
        <translation>Спрашивать игрока о подтверждении задания</translation>
    </message>
    <message>
        <source>Confirmation question: </source>
        <translation>Запрос на подтверждение:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Start condition: </source>
        <translation>Стартовое условие:</translation>
    </message>
    <message>
        <source>Fail condition: </source>
        <translation>Условие поражения:</translation>
    </message>
    <message>
        <source>Success condition: </source>
        <translation>Условие победы:</translation>
    </message>
</context>
<context>
    <name>ScenarioInfo</name>
    <message>
        <source>General Scenario Informations</source>
        <translation>Общая информация о сценарии</translation>
    </message>
    <message>
        <source>General Information</source>
        <translation>Общая информация</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Theme: </source>
        <translation>Тема:</translation>
    </message>
    <message>
        <source>Number of players: </source>
        <translation>Число игроков:</translation>
    </message>
    <message>
        <source>Map height: </source>
        <translation>Высота карты:</translation>
    </message>
    <message>
        <source>Map width: </source>
        <translation>Ширина карты:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Описание:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Map </source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Map for Attal</source>
        <translation>Карта Attal</translation>
    </message>
</context>
<context>
    <name>ScenarioInterface</name>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>&amp;Save as</source>
        <translation>&amp;Сохранить как</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Scenario information</source>
        <translation>Информация о сценарии</translation>
    </message>
    <message>
        <source>&amp;Scenario information</source>
        <translation>&amp;Информация о сценарии</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Players properties</source>
        <translation>Свойства игрока</translation>
    </message>
    <message>
        <source>&amp;Players properties</source>
        <translation>&amp;Свойства игрока</translation>
    </message>
    <message>
        <source>CTRL+P</source>
        <translation>CTRL+P</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Очистить экран</translation>
    </message>
    <message>
        <source>&amp;Clear screen</source>
        <translation>&amp;Очистить экран</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>Fill screen</source>
        <translation>Заполнить экран</translation>
    </message>
    <message>
        <source>&amp;Fill screen</source>
        <translation>&amp;Запонить экран</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Scenario</source>
        <translation>&amp;Сценарий</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Невозможно загрузить тему</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Тема</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>не была успешно загружена</translation>
    </message>
    <message>
        <source>Quests management</source>
        <translation>Управление заданиями</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Миникарта</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Миникарта</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
</context>
<context>
    <name>Screen</name>
    <message>
        <source>(Cell %dx%d)</source>
        <translation>(Ячейка %dx%d)</translation>
    </message>
</context>
<context>
    <name>TilePresentation</name>
    <message>
        <source>%d (weight=%d)</source>
        <translation>%d (ширина=%d)</translation>
    </message>
</context>
</TS>
